@@ -96,6 +96,15 @@ _user_schema = validate.Schema(
     },
     validate.get("display_name")
 )
+_stream_schema = validate.Schema(
+    {
+        "stream": validate.any(None, {
+            "stream_type": validate.any("live", "rerun"),
+            "broadcast_platform": validate.any("live", "rerun")
+        })
+    },
+    validate.get("stream")
+)
 _video_schema = validate.Schema(
     {
         "chunks": {
@@ -374,6 +383,12 @@ class Twitch(Plugin):
                        help="""
         Skip embedded advertisement segments at the beginning or during a stream.
         Will cause these segments to be missing from the stream.
+        """
+                       ),
+        PluginArgument("disable-reruns",
+                       action="store_true",
+                       help="""
+        Do not open the stream if the target channel is currently broadcasting a rerun.
         """
                        ))
 
@@ -444,7 +459,7 @@ class Twitch(Plugin):
                     self.video_type = self.params["video"][0]
                     self.video_id = self.params["video"][1:]
                 except IndexError:
-                    self.logger.debug("Invalid video param: {0}", self.params["video"])
+                    log.debug("Invalid video param: {0}".format(self.params["video"]))
             self._channel = self.params.get("channel")
         elif self.subdomain == "clips":
             # clip share URL
@@ -514,27 +529,25 @@ class Twitch(Plugin):
         cookies = self.options.get("cookie")
 
         if oauth_token:
-            self.logger.info("Attempting to authenticate using OAuth token")
+            log.info("Attempting to authenticate using OAuth token")
             self.api.oauth_token = oauth_token
             user = self.api.user(schema=_user_schema)
 
             if user:
-                self.logger.info("Successfully logged in as {0}", user)
+                log.info("Successfully logged in as {0}".format(user))
             else:
-                self.logger.error("Failed to authenticate, the access token "
-                                  "is invalid or missing required scope")
+                log.error("Failed to authenticate, the access token is invalid or missing required scope")
         elif cookies:
-            self.logger.info("Attempting to authenticate using cookies")
+            log.info("Attempting to authenticate using cookies")
 
             self.api.add_cookies(cookies)
             self.api.oauth_token = self.api.token(schema=_viewer_token_schema)
             login = self.api.viewer_info(schema=_viewer_info_schema)
 
             if login:
-                self.logger.info("Successfully logged in as {0}", login)
+                log.info("Successfully logged in as {0}".format(login))
             else:
-                self.logger.error("Failed to authenticate, your cookies "
-                                  "may have expired")
+                log.error("Failed to authenticate, your cookies may have expired")
 
     def _create_playlist_streams(self, videos):
         start_offset = int(videos.get("start_offset", 0))
@@ -544,9 +557,7 @@ class Twitch(Plugin):
         for quality, chunks in videos.get("chunks").items():
             if not chunks:
                 if videos.get("restrictions", {}).get(quality) == "chansub":
-                    self.logger.warning("The quality '{0}' is not available "
-                                        "since it requires a subscription.",
-                                        quality)
+                    log.warning("The quality '{0}' is not available since it requires a subscription.".format(quality))
                 continue
 
             # Rename 'live' to 'source'
@@ -555,8 +566,7 @@ class Twitch(Plugin):
 
             chunks_filtered = list(filter(lambda c: c["url"], chunks))
             if len(chunks) != len(chunks_filtered):
-                self.logger.warning("The video '{0}' contains invalid chunks. "
-                                    "There will be missing data.", quality)
+                log.warning("The video '{0}' contains invalid chunks. There will be missing data.".format(quality))
                 chunks = chunks_filtered
 
             chunks_duration = sum(c.get("length") for c in chunks)
@@ -577,8 +587,7 @@ class Twitch(Plugin):
                                                      start_offset,
                                                      stop_offset)
                 except StreamError as err:
-                    self.logger.error("Error while creating video '{0}': {1}",
-                                      quality, err)
+                    log.error("Error while creating video '{0}': {1}".format(quality, err))
                     continue
 
             streams[quality] = stream
@@ -644,7 +653,7 @@ class Twitch(Plugin):
                            tags=playlist_tags, duration=playlist_duration)
 
     def _get_video_streams(self):
-        self.logger.debug("Getting video steams for {0} (type={1})".format(self.video_id, self.video_type))
+        log.debug("Getting video steams for {0} (type={1})".format(self.video_id, self.video_type))
         self._authenticate()
 
         if self.video_type == "b":
@@ -694,22 +703,31 @@ class Twitch(Plugin):
     def _check_for_host(self):
         host_info = self.api.hosted_channel(include_logins=1, host=self.channel_id).json()["hosts"][0]
         if "target_login" in host_info and host_info["target_login"].lower() != self.channel.lower():
-            self.logger.info("{0} is hosting {1}".format(self.channel, host_info["target_login"]))
+            log.info("{0} is hosting {1}".format(self.channel, host_info["target_login"]))
             return host_info["target_login"]
 
+    def _check_for_rerun(self):
+        stream = self.api.streams(self.channel_id, schema=_stream_schema)
+
+        return stream and (stream["stream_type"] == "rerun" or stream["broadcast_platform"] == "rerun")
+
     def _get_hls_streams(self, stream_type="live"):
-        self.logger.debug("Getting {0} HLS streams for {1}".format(stream_type, self.channel))
+        log.debug("Getting {0} HLS streams for {1}".format(stream_type, self.channel))
         self._authenticate()
         self._hosted_chain.append(self.channel)
 
         if stream_type == "live":
+            if self.options.get("disable_reruns") and self._check_for_rerun():
+                log.info("Reruns were disabled by command line option")
+                return {}
+
             hosted_channel = self._check_for_host()
             if hosted_channel and self.options.get("disable_hosting"):
-                self.logger.info("hosting was disabled by command line option")
+                log.info("hosting was disabled by command line option")
             elif hosted_channel:
-                self.logger.info("switching to {0}", hosted_channel)
+                log.info("switching to {0}".format(hosted_channel))
                 if hosted_channel in self._hosted_chain:
-                    self.logger.error(
+                    log.error(
                         u"A loop of hosted channels has been detected, "
                         "cannot find a playable stream. ({0})".format(
                             u" -> ".join(self._hosted_chain + [hosted_channel])))
@@ -724,7 +742,7 @@ class Twitch(Plugin):
             sig, token = self._access_token(stream_type)
             url = self.usher.video(self.video_id, nauthsig=sig, nauth=token)
         else:
-            self.logger.debug("Unknown HLS stream type: {0}".format(stream_type))
+            log.debug("Unknown HLS stream type: {0}".format(stream_type))
             return {}
 
         time_offset = self.params.get("t", 0)
@@ -754,9 +772,7 @@ class Twitch(Plugin):
             token = parse_json(token, schema=_token_schema)
             for name in token["restricted_bitrates"]:
                 if name not in streams:
-                    self.logger.warning("The quality '{0}' is not available "
-                                        "since it requires a subscription.",
-                                        name)
+                    log.warning("The quality '{0}' is not available since it requires a subscription.".format(name))
         except PluginError:
             pass
 
