@@ -1,15 +1,15 @@
+import functools
 import json
 import re
+import xml.etree.ElementTree as ET
 import zlib
 
-try:
-    import xml.etree.cElementTree as ET
-except ImportError:  # pragma: no cover
-    import xml.etree.ElementTree as ET
-
-from streamlink.compat import urljoin, urlparse, parse_qsl, is_py2, urlunparse
+from streamlink.compat import urljoin, urlparse, parse_qsl, is_py2, is_py3
 from streamlink.exceptions import PluginError
 from streamlink.utils.named_pipe import NamedPipe
+from streamlink.utils.lazy_formatter import LazyFormatter
+from streamlink.utils.encoding import get_filesystem_encoding, maybe_decode, maybe_encode
+from streamlink.utils.url import update_scheme, url_equal
 
 
 def swfdecompress(data):
@@ -23,7 +23,7 @@ def verifyjson(json, key):
     if not isinstance(json, dict):
         raise PluginError("JSON result is not a dict")
 
-    if not key in json:
+    if key not in json:
         raise PluginError("Missing '{0}' key in JSON".format(key))
 
     return json[key]
@@ -67,7 +67,7 @@ def parse_json(data, name="JSON", exception=PluginError, schema=None):
     return json_data
 
 
-def parse_xml(data, name="XML", ignore_ns=False, exception=PluginError, schema=None):
+def parse_xml(data, name="XML", ignore_ns=False, exception=PluginError, schema=None, invalid_char_entities=False):
     """Wrapper around ElementTree.fromstring with some extras.
 
     Provides these extra features:
@@ -77,9 +77,14 @@ def parse_xml(data, name="XML", ignore_ns=False, exception=PluginError, schema=N
     """
     if is_py2 and isinstance(data, unicode):
         data = data.encode("utf8")
+    elif is_py3 and isinstance(data, str):
+        data = bytearray(data, "utf8")
 
     if ignore_ns:
-        data = re.sub(" xmlns=\"(.+?)\"", "", data)
+        data = re.sub(br"[\t ]xmlns=\"(.+?)\"", b"", data)
+
+    if invalid_char_entities:
+        data = re.sub(br'&(?!(?:#(?:[0-9]+|[Xx][0-9A-Fa-f]+)|[A-Za-z0-9]+);)', b'&amp;', data)
 
     try:
         tree = ET.fromstring(data)
@@ -134,112 +139,67 @@ def rtmpparse(url):
     return tcurl, playpath
 
 
-def update_scheme(current, target):
+def memoize(obj):
+    cache = obj.cache = {}
+
+    @functools.wraps(obj)
+    def memoizer(*args, **kwargs):
+        key = str(args) + str(kwargs)
+        if key not in cache:
+            cache[key] = obj(*args, **kwargs)
+        return cache[key]
+    return memoizer
+
+
+def search_dict(data, key):
     """
-    Take the scheme from the current URL and applies it to the
-    target URL if the target URL startswith // or is missing a scheme
-    :param current: current URL
-    :param target: target URL
-    :return: target URL with the current URLs scheme
+    Search for a key in a nested dict, or list of nested dicts, and return the values.
+
+    :param data: dict/list to search
+    :param key: key to find
+    :return: matches for key
     """
-    target_p = urlparse(target)
-    if not target_p.scheme and target_p.netloc:
-        return "{0}:{1}".format(urlparse(current).scheme,
-                                urlunparse(target_p))
-    elif not target_p.scheme and not target_p.netloc:
-        return "{0}://{1}".format(urlparse(current).scheme,
-                                  urlunparse(target_p))
-    else:
-        return target
+    if isinstance(data, dict):
+        for dkey, value in data.items():
+            if dkey == key:
+                yield value
+            for result in search_dict(value, key):
+                yield result
+    elif isinstance(data, list):
+        for value in data:
+            for result in search_dict(value, key):
+                yield result
 
 
-#####################################
-# Deprecated functions, do not use. #
-#####################################
+def load_module(name, path=None):
+    if is_py3:
+        import importlib.machinery
+        import importlib.util
+        import sys
 
-import requests
-
-
-def urlget(url, *args, **kwargs):  # pragma: no cover
-    """This function is deprecated."""
-    data = kwargs.pop("data", None)
-    exception = kwargs.pop("exception", PluginError)
-    method = kwargs.pop("method", "GET")
-    session = kwargs.pop("session", None)
-    timeout = kwargs.pop("timeout", 20)
-
-    if data is not None:
-        method = "POST"
-
-    try:
-        if session:
-            res = session.request(method, url, timeout=timeout, data=data,
-                                  *args, **kwargs)
+        loader_details = [(importlib.machinery.SourceFileLoader, importlib.machinery.SOURCE_SUFFIXES)]
+        finder = importlib.machinery.FileFinder(path, *loader_details)
+        spec = finder.find_spec(name)
+        if not spec or not spec.loader:
+            raise ImportError("no module named {0}".format(name))
+        if sys.version_info[1] > 4:
+            mod = importlib.util.module_from_spec(spec)
+            spec.loader.exec_module(mod)
+            return mod
         else:
-            res = requests.request(method, url, timeout=timeout, data=data,
-                                   *args, **kwargs)
+            return spec.loader.load_module(name)
 
-        res.raise_for_status()
-    except (requests.exceptions.RequestException, IOError) as rerr:
-        err = exception("Unable to open URL: {url} ({err})".format(url=url,
-                                                                   err=rerr))
-        err.err = rerr
-        raise err
-
-    return res
-
-
-urlopen = urlget
-
-
-def urlresolve(url):  # pragma: no cover
-    """This function is deprecated."""
-    res = urlget(url, stream=True, allow_redirects=False)
-
-    if res.status_code == 302 and "location" in res.headers:
-        return res.headers["location"]
     else:
-        return url
+        import imp
+        fd, filename, desc = imp.find_module(name, path and [path])
+        try:
+            return imp.load_module(name, fd, filename, desc)
+        finally:
+            if fd:
+                fd.close()
 
 
-def res_xml(res, *args, **kw):  # pragma: no cover
-    """This function is deprecated."""
-    return parse_xml(res.text, *args, **kw)
-
-
-def res_json(res, jsontype="JSON", exception=PluginError):  # pragma: no cover
-    """This function is deprecated."""
-    try:
-        jsondata = res.json()
-    except ValueError as err:
-        if len(res.text) > 35:
-            snippet = res.text[:35] + "..."
-        else:
-            snippet = res.text
-
-        raise exception("Unable to parse {0}: {1} ({2})".format(jsontype, err,
-                                                                snippet))
-
-    return jsondata
-
-
-import hmac
-import hashlib
-
-SWF_KEY = b"Genuine Adobe Flash Player 001"
-
-
-def swfverify(url):  # pragma: no cover
-    """This function is deprecated."""
-    res = urlopen(url)
-    swf = swfdecompress(res.content)
-
-    h = hmac.new(SWF_KEY, swf, hashlib.sha256)
-
-    return h.hexdigest(), len(swf)
-
-
-def escape_librtmp(value):
+def escape_librtmp(value):  # pragma: no cover
     if isinstance(value, bool):
         value = "1" if value else "0"
     if isinstance(value, int):
@@ -252,7 +212,8 @@ def escape_librtmp(value):
     return value
 
 
-__all__ = ["urlopen", "urlget", "urlresolve", "swfdecompress", "swfverify",
-           "verifyjson", "absolute_url", "parse_qsd", "parse_json", "res_json",
-           "parse_xml", "res_xml", "rtmpparse", "prepend_www", "NamedPipe",
-           "escape_librtmp"]
+__all__ = ["swfdecompress", "update_scheme", "url_equal",
+           "verifyjson", "absolute_url", "parse_qsd", "parse_json",
+           "parse_xml", "rtmpparse", "prepend_www", "NamedPipe",
+           "escape_librtmp", "LazyFormatter", "get_filesystem_encoding",
+           "maybe_decode", "maybe_encode"]
